fn interest_to_pending_bit(interest: InterestType) -> u8Expand description
Maps a source interest callback variant into the internal pending-bit mask.
fn interest_to_pending_bit(interest: InterestType) -> u8Maps a source interest callback variant into the internal pending-bit mask.