register_epoll_handler

Function register_epoll_handler 

pub(crate) fn register_epoll_handler(
    state: &Arc<WasiState>,
    event: &EpollFd,
    epoll_state: Arc<EpollState>,
    sub_state: Arc<EpollSubState>,
) -> Result<Option<EpollJoinGuard>, Errno>
Registers an epoll interest handler on the watched fd and returns a guard.

None means the fd kind does not support handler attachment for epoll.