run_setup_hooks

Function run_setup_hooks 

fn run_setup_hooks(
    hooks: &[Arc<dyn InstantiationHook>],
    states: Vec<InstantiationState>,
    module: &Module,
    store: &mut StoreMut<'_>,
    instance: &Instance,
    imported_memory: Option<&Memory>,
) -> Result<()>
Runs the setup phase of hooks, handing each hook the state it produced during the import phase.