pub struct BuiltinPackageLoader {
client: Arc<dyn HttpClient + Send + Sync>,
in_memory: Option<InMemoryCache>,
cache: Option<FileSystemCache>,
tokens: HashMap<String, String>,
hash_validation: HashIntegrityValidationMode,
}Expand description
The builtin PackageLoader that is used by the wasmer CLI and
respects $WASMER_DIR.
Fields
client: Arc<dyn HttpClient + Send + Sync>in_memory: Option<InMemoryCache>cache: Option<FileSystemCache>tokens: HashMap<String, String>A mapping from hostnames to tokens
hash_validation: HashIntegrityValidationModeImplementations
Sourceimpl BuiltinPackageLoader
impl BuiltinPackageLoader
pub fn new() -> Self
Sourcepub fn with_hash_validation_mode(
self,
mode: HashIntegrityValidationMode,
) -> Self
pub fn with_hash_validation_mode( self, mode: HashIntegrityValidationMode, ) -> Self
Set the validation mode to apply after downloading an image.
See HashIntegrityValidationMode for details.
pub fn with_cache_dir(self, cache_dir: impl Into<PathBuf>) -> Self
Sourcepub fn without_in_memory_cache(self) -> Self
pub fn without_in_memory_cache(self) -> Self
Disable promotion of loaded containers into the in-memory cache.
pub fn cache(&self) -> Option<&FileSystemCache>
pub fn validate_cache( &self, mode: CacheValidationMode, ) -> Result<Vec<ImageHashMismatchError>, Error>
pub fn with_http_client( self, client: impl HttpClient + Send + Sync + 'static, ) -> Self
pub fn with_tokens<I, K, V>(self, tokens: I) -> Self
Sourcepub fn with_token(
self,
hostname: impl Into<String>,
token: impl Into<String>,
) -> Self
pub fn with_token( self, hostname: impl Into<String>, token: impl Into<String>, ) -> Self
Add an API token that will be used whenever sending requests to a particular hostname.
Note that this uses Url::authority() when looking up tokens, so it
will match both plain hostnames (e.g. registry.wasmer.io) and hosts
with a port number (e.g. localhost:8000).
Sourcepub fn insert_cached(&self, hash: WebcHash, container: &Container)
pub fn insert_cached(&self, hash: WebcHash, container: &Container)
Insert a container into the in-memory hash.
Sourcepub fn evict_cached(&self, hash: &WebcHash) -> Option<Container>
pub fn evict_cached(&self, hash: &WebcHash) -> Option<Container>
Remove a container from the in-memory cache.
async fn get_cached(&self, hash: &WebcHash) -> Result<Option<Container>, Error>
Sourceasync fn validate_hash(
image: &Bytes,
mode: HashIntegrityValidationMode,
info: &DistributionInfo,
) -> Result<(), Error>
async fn validate_hash( image: &Bytes, mode: HashIntegrityValidationMode, info: &DistributionInfo, ) -> Result<(), Error>
Validate image contents with the specified validation mode.
Sourcefn validate_hash_sync(
image: &[u8],
mode: HashIntegrityValidationMode,
info: &DistributionInfo,
) -> Result<(), Error>
fn validate_hash_sync( image: &[u8], mode: HashIntegrityValidationMode, info: &DistributionInfo, ) -> Result<(), Error>
Validate image contents with the specified validation mode.
async fn download(&self, dist: &DistributionInfo) -> Result<Bytes, Error>
fn headers(&self, url: &Url) -> HeaderMap
Sourcefn decode_response_body(
headers: &HeaderMap,
body: Vec<u8>,
) -> Result<Vec<u8>, Error>
fn decode_response_body( headers: &HeaderMap, body: Vec<u8>, ) -> Result<Vec<u8>, Error>
Decode the response body according to the Content-Encoding header.
- Supports
gzipandzstdencodings - Supports nested encodings (e.g.
gzip, zstd) - Passes through unencoded bodies or “identity” encoding unchanged