pub async fn resolve_dependency_graph(
root_id: &PackageId,
root: &PackageInfo,
source: &dyn Source,
) -> Result<DependencyGraph, ResolveError>Expand description
Given the PackageInfo for a root package, discover its dependency graph.
Unlike resolve(), this only queries and links packages. It does not apply
runtime compatibility checks such as rejecting duplicate package versions.