PluggableRuntime

Struct PluggableRuntime 

pub struct PluggableRuntime {
    pub rt: Arc<dyn VirtualTaskManager>,
    pub networking: DynVirtualNetworking,
    pub http_client: Option<DynHttpClient>,
    pub package_loader: Arc<dyn PackageLoader + Send + Sync>,
    pub source: Arc<dyn Source + Send + Sync>,
    pub engine: Engine,
    pub module_cache: Arc<dyn ModuleCache + Send + Sync>,
    pub tty: Option<Arc<dyn TtyBridge + Send + Sync>>,
    pub read_only_journals: Vec<Arc<DynReadableJournal>>,
    pub writable_journals: Vec<Arc<DynJournal>>,
    pub instantiation_hooks: Vec<Arc<dyn InstantiationHook>>,
}

Fields

rt: Arc<dyn VirtualTaskManager>networking: DynVirtualNetworkinghttp_client: Option<DynHttpClient>package_loader: Arc<dyn PackageLoader + Send + Sync>source: Arc<dyn Source + Send + Sync>engine: Enginemodule_cache: Arc<dyn ModuleCache + Send + Sync>tty: Option<Arc<dyn TtyBridge + Send + Sync>>read_only_journals: Vec<Arc<DynReadableJournal>>writable_journals: Vec<Arc<DynJournal>>instantiation_hooks: Vec<Arc<dyn InstantiationHook>>

Implementations

Source

impl PluggableRuntime

pub fn new(rt: Arc<dyn VirtualTaskManager>) -> Self

pub fn set_networking_implementation<I>(&mut self, net: I) -> &mut Self

pub fn set_engine(&mut self, engine: Engine) -> &mut Self

pub fn set_tty(&mut self, tty: Arc<dyn TtyBridge + Send + Sync>) -> &mut Self

pub fn set_module_cache( &mut self, module_cache: impl ModuleCache + Send + Sync + 'static, ) -> &mut Self

pub fn set_source(&mut self, source: impl Source + Send + 'static) -> &mut Self

pub fn set_package_loader( &mut self, package_loader: impl PackageLoader + 'static, ) -> &mut Self

pub fn set_http_client( &mut self, client: impl HttpClient + Send + Sync + 'static, ) -> &mut Self

pub fn add_read_only_journal( &mut self, journal: Arc<DynReadableJournal>, ) -> &mut Self

pub fn add_writable_journal(&mut self, journal: Arc<DynJournal>) -> &mut Self

pub fn with_additional_imports( &mut self, imports: impl Fn(&Module, &mut StoreMut<'_>) -> Result<Imports> + Send + Sync + 'static, ) -> &mut Self

Registers a hook that only creates additional imports.

pub fn with_instance_setup( &mut self, callback: impl Fn(&Module, &mut StoreMut<'_>, &Instance, Option<&Memory>) -> Result<()> + Send + Sync + 'static, ) -> &mut Self

Registers a hook that only configures newly created instances.

pub fn with_instantiation_hook( &mut self, hook: impl InstantiationHook, ) -> &mut Self

Registers a hook that takes part in both phases of instantiation, so it can carry InstantiationState from its imports to its instance setup.