pub(super) struct LinkerState {Show 14 fields
pub(super) engine: Engine,
pub(super) main_module: Module,
pub(super) main_module_dylink_info: DylinkInfo,
pub(super) main_module_memory_base: u64,
pub(super) side_modules: BTreeMap<ModuleHandle, DlModule>,
pub(super) side_modules_by_name: HashMap<PathBuf, ModuleHandle>,
pub(super) next_module_handle: u32,
pub(super) memory_allocator: MemoryAllocator,
pub(super) heap_base: u64,
pub(super) allocated_closure_functions: BTreeMap<u32, bool>,
pub(super) available_closure_functions: Vec<u32>,
pub(super) symbol_resolution_records: HashMap<SymbolResolutionKey, SymbolResolutionResult>,
pub(super) send_pending_operation_barrier: Bus<Arc<Barrier>>,
pub(super) send_pending_operation: Bus<DlOperation>,
}Fields
engine: Enginemain_module: Modulemain_module_dylink_info: DylinkInfomain_module_memory_base: u64side_modules: BTreeMap<ModuleHandle, DlModule>side_modules_by_name: HashMap<PathBuf, ModuleHandle>next_module_handle: u32memory_allocator: MemoryAllocatorheap_base: u64allocated_closure_functions: BTreeMap<u32, bool>Tracks which slots in the function table are currently used for closures
True if the closure is currently in use, false otherwise.
available_closure_functions: Vec<u32>Slots in the indirect function table that were allocated for closures but are currently not in use. These can be given out without needing to lock all threads.
symbol_resolution_records: HashMap<SymbolResolutionKey, SymbolResolutionResult>send_pending_operation_barrier: Bus<Arc<Barrier>>send_pending_operation: Bus<DlOperation>Implementations
Sourceimpl LinkerState
impl LinkerState
pub(super) fn allocate_memory( &mut self, store: &mut impl AsStoreMut, memory: &Memory, mem_info: &MemInfo, ) -> Result<u64, MemoryError>
pub(super) fn memory_base(&self, module_handle: ModuleHandle) -> u64
pub(super) fn dylink_info(&self, module_handle: ModuleHandle) -> &DylinkInfo
pub(super) fn resolve_symbols( &self, group: &InstanceGroupState, store: &mut impl AsStoreMut, module: &Module, module_handle: ModuleHandle, link_state: &mut InProgressLinkState, well_known_imports: &[(&str, &str, u64)], ) -> Result<(), LinkError>
fn resolve_env_symbol( &self, group: &InstanceGroupState, import: &ImportType, store: &impl AsStoreRef, ) -> Result<InProgressSymbolResolution, LinkError>
fn resolve_got_mem_symbol( &self, group: &InstanceGroupState, import: &ImportType, store: &impl AsStoreRef, ) -> Result<InProgressSymbolResolution, LinkError>
fn resolve_got_func_symbol( &self, group: &InstanceGroupState, import: &ImportType, store: &impl AsStoreRef, ) -> Result<InProgressSymbolResolution, LinkError>
pub(super) fn load_module_tree( &mut self, module_spec: DlModuleSpec<'_>, link_state: &mut InProgressLinkState, runtime: &Arc<dyn Runtime + Send + Sync + 'static>, wasi_state: &WasiState, runtime_path: &[impl AsRef<str>], calling_module_path: Option<impl AsRef<Path>>, ) -> Result<ModuleHandle, LinkError>