Global

Struct Global 

pub(crate) struct Global(pub(crate) BackendGlobal);
A WebAssembly global instance.

A global instance is the runtime representation of a global variable. It consists of an individual value and a flag indicating whether it is mutable.

Spec: https://webassembly.github.io/spec/core/exec/runtime.html#global-instances

Tuple Fields

0: BackendGlobal

Implementations

Source

impl Global

pub fn new(store: &mut impl AsStoreMut, val: Value) -> Global

Create a new global with the initial Value.

Example
let g = Global::new(&mut store, Value::I32(1));

assert_eq!(g.get(&mut store), Value::I32(1));
assert_eq!(g.ty(&mut store).mutability, Mutability::Const);
pub fn new_mut(store: &mut impl AsStoreMut, val: Value) -> Global

Create a mutable global with the initial Value.

Example
let g = Global::new_mut(&mut store, Value::I32(1));

assert_eq!(g.get(&mut store), Value::I32(1));
assert_eq!(g.ty(&mut store).mutability, Mutability::Var);
pub fn ty(&self, store: &impl AsStoreRef) -> GlobalType

Returns the GlobalType of the global.

Example
let c = Global::new(&mut store, Value::I32(1));
let v = Global::new_mut(&mut store, Value::I64(1));

assert_eq!(c.ty(&mut store), GlobalType::new(Type::I32, Mutability::Const));
assert_eq!(v.ty(&mut store), GlobalType::new(Type::I64, Mutability::Var));
pub fn get(&self, store: &mut impl AsStoreMut) -> Value

Retrieves the current value Value that the global has.

Example
let g = Global::new(&mut store, Value::I32(1));

assert_eq!(g.get(&mut store), Value::I32(1));
pub fn set( &self, store: &mut impl AsStoreMut, val: Value, ) -> Result<(), RuntimeError>

Sets a custom Value to the runtime global.

Example
let g = Global::new_mut(&mut store, Value::I32(1));

assert_eq!(g.get(&mut store), Value::I32(1));

g.set(&mut store, Value::I32(2));

assert_eq!(g.get(&mut store), Value::I32(2));
Errors

Trying to mutate a immutable global will raise an error:

let g = Global::new(&mut store, Value::I32(1));

g.set(&mut store, Value::I32(2)).unwrap();

Trying to set a value of a incompatible type will raise an error:

let g = Global::new(&mut store, Value::I32(1));

// This results in an error: `RuntimeError`.
g.set(&mut store, Value::I64(2)).unwrap();
pub fn is_from_store(&self, store: &impl AsStoreRef) -> bool

Checks whether this global can be used with the given context.