pub(crate) trait DerefMut: Deref {
// Required method
fn deref_mut(&mut self) -> &mut Self::Target;
}Expand description
Used for mutable dereferencing operations, like in *v = 1;.
In addition to being used for explicit dereferencing operations with the
(unary) * operator in mutable contexts, DerefMut is also used implicitly
by the compiler in many circumstances. This mechanism is called
“mutable deref coercion”. In immutable contexts, Deref is used.
Warning: Deref coercion is a powerful language feature which has
far-reaching implications for every type that implements DerefMut. The
compiler will silently insert calls to DerefMut::deref_mut. For this
reason, one should be careful about implementing DerefMut and only do so
when mutable deref coercion is desirable. See the Deref docs
for advice on when this is typically desirable or undesirable.
Types that implement DerefMut or Deref are often called “smart
pointers” and the mechanism of deref coercion has been specifically designed
to facilitate the pointer-like behavior that name suggests. Often, the
purpose of a “smart pointer” type is to change the ownership semantics
of a contained value (for example, Rc or Cow) or the
storage semantics of a contained value (for example, Box).
Mutable deref coercion
If T implements DerefMut<Target = U>, and v is a value of type T,
then:
- In mutable contexts,
*v(whereTis neither a reference nor a raw pointer) is equivalent to*DerefMut::deref_mut(&mut v). - Values of type
&mut Tare coerced to values of type&mut U Timplicitly implements all the (mutable) methods of the typeU.
For more details, visit the chapter in The Rust Programming Language as well as the reference sections on the dereference operator, method resolution and type coercions.
Fallibility
This trait’s method should never unexpectedly fail. Deref coercion means
the compiler will often insert calls to DerefMut::deref_mut implicitly.
Failure during dereferencing can be extremely confusing when DerefMut is
invoked implicitly. In the majority of uses it should be infallible, though
it may be acceptable to panic if the type is misused through programmer
error, for example.
However, infallibility is not enforced and therefore not guaranteed.
As such, unsafe code should not rely on infallibility in general for
soundness.
Examples
A struct with a single field which is modifiable by dereferencing the struct.
use std::ops::{Deref, DerefMut};
struct DerefMutExample<T> {
value: T
}
impl<T> Deref for DerefMutExample<T> {
type Target = T;
fn deref(&self) -> &Self::Target {
&self.value
}
}
impl<T> DerefMut for DerefMutExample<T> {
fn deref_mut(&mut self) -> &mut Self::Target {
&mut self.value
}
}
let mut x = DerefMutExample { value: 'a' };
*x = 'b';
assert_eq!('b', x.value);Required Methods
Implementors
impl<T> !DerefMut for &Twhere
T: ?Sized,
impl DerefMut for TrackedVec
impl DerefMut for InodeValFileWriteGuard
impl DerefMut for WasiInstanceGuardMut<'_>
impl DerefMut for ByteString
impl DerefMut for String
impl DerefMut for ByteStr
impl DerefMut for OsString
impl DerefMut for PathBuf
impl DerefMut for Error
std or non-anyhow_no_core_error only.impl DerefMut for BytesMut
impl DerefMut for BStr
impl DerefMut for BString
impl DerefMut for BorrowedPayload<'_>
impl DerefMut for Buffer<'_>
impl DerefMut for ClientConnection
impl DerefMut for ClientConnection
impl DerefMut for ColoredString
impl DerefMut for Connection
impl DerefMut for Connection
impl DerefMut for Function
impl DerefMut for MmapMut
impl DerefMut for MmapMut
impl DerefMut for MutableBuffer
impl DerefMut for ServerConnection
impl DerefMut for ServerConnection
impl DerefMut for Termios
impl DerefMut for TryString
impl DerefMut for UnbufferedClientConnection
impl DerefMut for UnbufferedServerConnection
impl DerefMut for VariableArgs
impl<'a> DerefMut for IoSliceMut<'a>
impl<'a> DerefMut for MaybeUninitSlice<'a>
impl<'a, R, T> DerefMut for MappedMutexGuard<'a, R, T>where
R: RawMutex + 'a,
T: 'a + ?Sized,
impl<'a, R, T> DerefMut for MappedRwLockWriteGuard<'a, R, T>where
R: RawRwLock + 'a,
T: 'a + ?Sized,
impl<'a, R, T> DerefMut for MutexGuard<'a, R, T>where
R: RawMutex + 'a,
T: 'a + ?Sized,
impl<'a, R, T> DerefMut for RwLockWriteGuard<'a, R, T>where
R: RawRwLock + 'a,
T: 'a + ?Sized,
impl<'a, T> DerefMut for AlignedCowVec<'a, T>
impl<'a, T> DerefMut for Locked<'a, T>
impl<'a, T> DerefMut for Managed<'a, T>where
T: 'a + ?Sized,
impl<'a, T> DerefMut for ManagedSlice<'a, T>where
T: 'a,
impl<'a, T> DerefMut for MappedMutexGuard<'a, T>where
T: ?Sized,
impl<'a, T, A> DerefMut for alloc::vec::peek_mut::PeekMut<'a, T, A>where
A: Allocator,
impl<'a, T, C> DerefMut for sharded_slab::pool::RefMut<'a, T, C>
impl<'a, T, F> DerefMut for PoolGuard<'a, T, F>
impl<'i> DerefMut for DeArray<'i>
impl<A> DerefMut for SmallVec<A>where
A: Array,
impl<B, T> DerefMut for Ref<B, T>where
B: ByteSliceMut,
T: FromBytes + IntoBytes + KnownLayout + Immutable + ?Sized,
impl<Data> DerefMut for ConnectionCommon<Data>
impl<K, V> DerefMut for RefMut<'_, K, V>
impl<K, V> DerefMut for RefMutMulti<'_, K, V>
impl<K, V, T> DerefMut for MappedRefMut<'_, K, V, T>
impl<L, R> DerefMut for Either<L, R>
impl<LenT, S> DerefMut for StringInner<LenT, S>where
LenT: LenType,
S: StringStorage + ?Sized,
impl<Ptr> DerefMut for Pin<Ptr>
impl<S> DerefMut for Ascii<S>
impl<S> DerefMut for BlockingStream<S>where
S: Stream + Unpin,
impl<S> DerefMut for UniCase<S>
impl<T> DerefMut for &mut Twhere
T: ?Sized,
impl<T> DerefMut for wasmer_wasix::journal::effector::MutexGuard<'_, T>where
T: ?Sized,
impl<T> DerefMut for wasmer_wasix::utils::owned_mutex_guard::OwnedRwLockWriteGuard<T>
impl<T> DerefMut for ThinBox<T>where
T: ?Sized,
impl<T> DerefMut for core::cell::RefMut<'_, T>where
T: ?Sized,
impl<T> DerefMut for ManuallyDrop<T>where
T: ?Sized,
impl<T> DerefMut for AssertUnwindSafe<T>
impl<T> DerefMut for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>where
T: ?Sized,
impl<T> DerefMut for std::sync::nonpoison::mutex::MutexGuard<'_, T>where
T: ?Sized,
impl<T> DerefMut for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> DerefMut for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> DerefMut for std::sync::poison::mutex::MappedMutexGuard<'_, T>where
T: ?Sized,
impl<T> DerefMut for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> DerefMut for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> DerefMut for Align<T>where
T: ?Sized,
impl<T> DerefMut for CachePadded<T>
impl<T> DerefMut for ConnectionCommon<T>
impl<T> DerefMut for Flock<T>where
T: Flockable,
fs and neither Redox nor Solaris only.