pub(crate) struct Store {
pub(crate) inner: Box<StoreInner>,
}Expand description
The store represents all global state that can be manipulated by WebAssembly programs. It consists of the runtime representation of all instances of functions, tables, memories, and globals that have been allocated during the lifetime of the abstract machine.
The Store is tied to the underlying Engine that is — among many things — used to
compile the Wasm bytes into a valid module artifact.
For more informations, check out the [related WebAssembly specification] [related WebAssembly specification]: https://webassembly.github.io/spec/core/exec/runtime.html#store
Fields
inner: Box<StoreInner>Implementations
Sourceimpl Store
impl Store
Sourcepub fn set_trap_handler(
&mut self,
handler: Option<Box<dyn Fn(i32, *const siginfo_t, *const c_void) -> bool + Sync + Send>>,
)
pub fn set_trap_handler( &mut self, handler: Option<Box<dyn Fn(i32, *const siginfo_t, *const c_void) -> bool + Sync + Send>>, )
Set the [TrapHandlerFn] for this store.
Note
Not every implementor allows changing the trap handler. In those store that don’t allow it, this function has no effect.
Sourcepub fn engine_mut(&mut self) -> &mut Engine
pub fn engine_mut(&mut self) -> &mut Engine
Returns mutable reference to Engine.
Sourcepub fn same(a: &Store, b: &Store) -> bool
pub fn same(a: &Store, b: &Store) -> bool
Checks whether two stores are identical. A store is considered equal to another store if both have the same engine.
Sourcepub fn interrupter(&self) -> Interrupter
pub fn interrupter(&self) -> Interrupter
Builds an Interrupter for this store. Calling Interrupter::interrupt
will cause running WASM code to terminate immediately with a
HostInterrupt trap.
Best effort is made to ensure interrupts are handled. However, there is no guarantee; under rare circumstances, it is possible for the interrupt to be missed. One such case is when the target thread is about to call WASM code but has not yet made the call.
To make sure the code is interrupted, the target thread should notify the signalling thread that it has finished running in some way, and the signalling thread must wait for that notification and retry the interrupt if the notification is not received after some time. Embedders are expected to implement this logic.
If an interrupt is delivered while an imported function is running, the interrupt will simply be stored and processed only when the imported function returns control to WASM code. No effort is made to interrupt running imported functions. Embedders are expected to implement support for interruption of long-running or blocking imported functions separately.
Sourcepub fn into_async(self) -> StoreAsync
pub fn into_async(self) -> StoreAsync
Transforms this store into a StoreAsync which can be used
to invoke Function::call_async.